from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media
import win32more.Windows.Win32.Media.Multimedia
import win32more.Windows.Win32.System.Com
TIMERR_NOERROR: UInt32 = 0
TIMERR_NOCANDO: UInt32 = 97
TIMERR_STRUCT: UInt32 = 129
MAXPNAMELEN: UInt32 = 32
MAXERRORLENGTH: UInt32 = 256
MM_MICROSOFT: UInt32 = 1
MM_MIDI_MAPPER: UInt32 = 1
MM_WAVE_MAPPER: UInt32 = 2
MM_SNDBLST_MIDIOUT: UInt32 = 3
MM_SNDBLST_MIDIIN: UInt32 = 4
MM_SNDBLST_SYNTH: UInt32 = 5
MM_SNDBLST_WAVEOUT: UInt32 = 6
MM_SNDBLST_WAVEIN: UInt32 = 7
MM_ADLIB: UInt32 = 9
MM_MPU401_MIDIOUT: UInt32 = 10
MM_MPU401_MIDIIN: UInt32 = 11
MM_PC_JOYSTICK: UInt32 = 12
TIME_MS: UInt32 = 1
TIME_SAMPLES: UInt32 = 2
TIME_BYTES: UInt32 = 4
TIME_SMPTE: UInt32 = 8
TIME_MIDI: UInt32 = 16
TIME_TICKS: UInt32 = 32
MM_JOY1MOVE: UInt32 = 928
MM_JOY2MOVE: UInt32 = 929
MM_JOY1ZMOVE: UInt32 = 930
MM_JOY2ZMOVE: UInt32 = 931
MM_JOY1BUTTONDOWN: UInt32 = 949
MM_JOY2BUTTONDOWN: UInt32 = 950
MM_JOY1BUTTONUP: UInt32 = 951
MM_JOY2BUTTONUP: UInt32 = 952
MM_MCINOTIFY: UInt32 = 953
MM_WOM_OPEN: UInt32 = 955
MM_WOM_CLOSE: UInt32 = 956
MM_WOM_DONE: UInt32 = 957
MM_WIM_OPEN: UInt32 = 958
MM_WIM_CLOSE: UInt32 = 959
MM_WIM_DATA: UInt32 = 960
MM_MIM_OPEN: UInt32 = 961
MM_MIM_CLOSE: UInt32 = 962
MM_MIM_DATA: UInt32 = 963
MM_MIM_LONGDATA: UInt32 = 964
MM_MIM_ERROR: UInt32 = 965
MM_MIM_LONGERROR: UInt32 = 966
MM_MOM_OPEN: UInt32 = 967
MM_MOM_CLOSE: UInt32 = 968
MM_MOM_DONE: UInt32 = 969
MM_DRVM_OPEN: UInt32 = 976
MM_DRVM_CLOSE: UInt32 = 977
MM_DRVM_DATA: UInt32 = 978
MM_DRVM_ERROR: UInt32 = 979
MM_STREAM_OPEN: UInt32 = 980
MM_STREAM_CLOSE: UInt32 = 981
MM_STREAM_DONE: UInt32 = 982
MM_STREAM_ERROR: UInt32 = 983
MM_MOM_POSITIONCB: UInt32 = 970
MM_MCISIGNAL: UInt32 = 971
MM_MIM_MOREDATA: UInt32 = 972
MM_MIXM_LINE_CHANGE: UInt32 = 976
MM_MIXM_CONTROL_CHANGE: UInt32 = 977
MMSYSERR_BASE: UInt32 = 0
WAVERR_BASE: UInt32 = 32
MIDIERR_BASE: UInt32 = 64
TIMERR_BASE: UInt32 = 96
JOYERR_BASE: UInt32 = 160
MCIERR_BASE: UInt32 = 256
MIXERR_BASE: UInt32 = 1024
MCI_STRING_OFFSET: UInt32 = 512
MCI_VD_OFFSET: UInt32 = 1024
MCI_CD_OFFSET: UInt32 = 1088
MCI_WAVE_OFFSET: UInt32 = 1152
MCI_SEQ_OFFSET: UInt32 = 1216
MMSYSERR_NOERROR: UInt32 = 0
MMSYSERR_ERROR: UInt32 = 1
MMSYSERR_BADDEVICEID: UInt32 = 2
MMSYSERR_NOTENABLED: UInt32 = 3
MMSYSERR_ALLOCATED: UInt32 = 4
MMSYSERR_INVALHANDLE: UInt32 = 5
MMSYSERR_NODRIVER: UInt32 = 6
MMSYSERR_NOMEM: UInt32 = 7
MMSYSERR_NOTSUPPORTED: UInt32 = 8
MMSYSERR_BADERRNUM: UInt32 = 9
MMSYSERR_INVALFLAG: UInt32 = 10
MMSYSERR_INVALPARAM: UInt32 = 11
MMSYSERR_HANDLEBUSY: UInt32 = 12
MMSYSERR_INVALIDALIAS: UInt32 = 13
MMSYSERR_BADDB: UInt32 = 14
MMSYSERR_KEYNOTFOUND: UInt32 = 15
MMSYSERR_READERROR: UInt32 = 16
MMSYSERR_WRITEERROR: UInt32 = 17
MMSYSERR_DELETEERROR: UInt32 = 18
MMSYSERR_VALNOTFOUND: UInt32 = 19
MMSYSERR_NODRIVERCB: UInt32 = 20
MMSYSERR_MOREDATA: UInt32 = 21
MMSYSERR_LASTERROR: UInt32 = 21
TIME_ONESHOT: UInt32 = 0
TIME_PERIODIC: UInt32 = 1
TIME_CALLBACK_FUNCTION: UInt32 = 0
TIME_CALLBACK_EVENT_SET: UInt32 = 16
TIME_CALLBACK_EVENT_PULSE: UInt32 = 32
TIME_KILL_SYNCHRONOUS: UInt32 = 256
@winfunctype('WINMM.dll')
def timeGetSystemTime(pmmt: POINTER(win32more.Windows.Win32.Media.MMTIME), cbmmt: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def timeGetTime() -> UInt32: ...
@winfunctype('WINMM.dll')
def timeGetDevCaps(ptc: POINTER(win32more.Windows.Win32.Media.TIMECAPS), cbtc: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def timeBeginPeriod(uPeriod: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def timeEndPeriod(uPeriod: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def timeSetEvent(uDelay: UInt32, uResolution: UInt32, fptc: win32more.Windows.Win32.Media.LPTIMECALLBACK, dwUser: UIntPtr, fuEvent: UInt32) -> UInt32: ...
@winfunctype('WINMM.dll')
def timeKillEvent(uTimerID: UInt32) -> UInt32: ...
HTASK = VoidPtr
class IReferenceClock(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{56a86897-0ad4-11ce-b03a-0020af0ba770}')
    @commethod(3)
    def GetTime(self, pTime: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AdviseTime(self, baseTime: Int64, streamTime: Int64, hEvent: win32more.Windows.Win32.Foundation.HANDLE, pdwAdviseCookie: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AdvisePeriodic(self, startTime: Int64, periodTime: Int64, hSemaphore: win32more.Windows.Win32.Foundation.HANDLE, pdwAdviseCookie: POINTER(UIntPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Unadvise(self, dwAdviseCookie: UIntPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IReferenceClock2(ComPtr):
    extends: win32more.Windows.Win32.Media.IReferenceClock
    _iid_ = Guid('{36b73885-c2c8-11cf-8b46-00805f6cef60}')
class IReferenceClockTimerControl(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ebec459c-2eca-4d42-a8af-30df557614b8}')
    @commethod(3)
    def SetDefaultTimerResolution(self, timerResolution: Int64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDefaultTimerResolution(self, pTimerResolution: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPDRVCALLBACK(hdrvr: win32more.Windows.Win32.Media.Multimedia.HDRVR, uMsg: UInt32, dwUser: UIntPtr, dw1: UIntPtr, dw2: UIntPtr) -> Void: ...
@winfunctype_pointer
def LPTIMECALLBACK(uTimerID: UInt32, uMsg: UInt32, dwUser: UIntPtr, dw1: UIntPtr, dw2: UIntPtr) -> Void: ...
class MMTIME(Structure):
    wType: UInt32
    u: _u_e__Union
    _pack_ = 1
    class _u_e__Union(Union):
        ms: UInt32
        sample: UInt32
        cb: UInt32
        ticks: UInt32
        smpte: _smpte_e__Struct
        midi: _midi_e__Struct
        _pack_ = 1
        class _smpte_e__Struct(Structure):
            hour: Byte
            min: Byte
            sec: Byte
            frame: Byte
            fps: Byte
            dummy: Byte
            pad: Byte * 2
        class _midi_e__Struct(Structure):
            songptrpos: UInt32
            _pack_ = 1
class TIMECAPS(Structure):
    wPeriodMin: UInt32
    wPeriodMax: UInt32
class TIMECODE(Union):
    Anonymous: _Anonymous_e__Struct
    qw: UInt64
    class _Anonymous_e__Struct(Structure):
        wFrameRate: UInt16
        wFrameFract: UInt16
        dwFrames: UInt32
class TIMECODE_SAMPLE(Structure):
    qwTick: Int64
    timecode: win32more.Windows.Win32.Media.TIMECODE
    dwUser: UInt32
    dwFlags: win32more.Windows.Win32.Media.TIMECODE_SAMPLE_FLAGS
TIMECODE_SAMPLE_FLAGS = UInt32
ED_DEVCAP_TIMECODE_READ: win32more.Windows.Win32.Media.TIMECODE_SAMPLE_FLAGS = 4121
ED_DEVCAP_ATN_READ: win32more.Windows.Win32.Media.TIMECODE_SAMPLE_FLAGS = 5047
ED_DEVCAP_RTC_READ: win32more.Windows.Win32.Media.TIMECODE_SAMPLE_FLAGS = 5050


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Printing
import win32more.Windows.UI.Xaml
import win32more.Windows.UI.Xaml.Printing
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class AddPagesEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Printing.IAddPagesEventArgs
    _classid_ = 'Windows.UI.Xaml.Printing.AddPagesEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Printing.AddPagesEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Printing.AddPagesEventArgs: ...
    @winrt_mixinmethod
    def get_PrintTaskOptions(self: win32more.Windows.UI.Xaml.Printing.IAddPagesEventArgs) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class AddPagesEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d4b57970-57a0-4209-847c-c093b54bc729}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Printing.AddPagesEventArgs) -> Void: ...
class GetPreviewPageEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Printing.IGetPreviewPageEventArgs
    _classid_ = 'Windows.UI.Xaml.Printing.GetPreviewPageEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Printing.GetPreviewPageEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Printing.GetPreviewPageEventArgs: ...
    @winrt_mixinmethod
    def get_PageNumber(self: win32more.Windows.UI.Xaml.Printing.IGetPreviewPageEventArgs) -> Int32: ...
    PageNumber = property(get_PageNumber, None)
class GetPreviewPageEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ccb3e9ed-9c11-4e50-ab49-e98086bbfdef}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Printing.GetPreviewPageEventArgs) -> Void: ...
class IAddPagesEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IAddPagesEventArgs'
    _iid_ = Guid('{e2e52be5-056c-4420-9795-cb3526ce0c20}')
    @winrt_commethod(6)
    def get_PrintTaskOptions(self) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class IGetPreviewPageEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IGetPreviewPageEventArgs'
    _iid_ = Guid('{a43d703d-dea9-4df6-a7ed-35049cd485c7}')
    @winrt_commethod(6)
    def get_PageNumber(self) -> Int32: ...
    PageNumber = property(get_PageNumber, None)
class IPaginateEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IPaginateEventArgs'
    _iid_ = Guid('{ed945fd6-79ab-42b7-930a-3d6e09011d21}')
    @winrt_commethod(6)
    def get_PrintTaskOptions(self) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    @winrt_commethod(7)
    def get_CurrentPreviewPageNumber(self) -> Int32: ...
    CurrentPreviewPageNumber = property(get_CurrentPreviewPageNumber, None)
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class IPrintDocument(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IPrintDocument'
    _iid_ = Guid('{e44327c3-a999-485b-b1d8-72dc517821e6}')
    @winrt_commethod(6)
    def get_DocumentSource(self) -> win32more.Windows.Graphics.Printing.IPrintDocumentSource: ...
    @winrt_commethod(7)
    def add_Paginate(self, handler: win32more.Windows.UI.Xaml.Printing.PaginateEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Paginate(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_GetPreviewPage(self, handler: win32more.Windows.UI.Xaml.Printing.GetPreviewPageEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_GetPreviewPage(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_AddPages(self, handler: win32more.Windows.UI.Xaml.Printing.AddPagesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_AddPages(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def AddPage(self, pageVisual: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(14)
    def AddPagesComplete(self) -> Void: ...
    @winrt_commethod(15)
    def SetPreviewPageCount(self, count: Int32, type: win32more.Windows.UI.Xaml.Printing.PreviewPageCountType) -> Void: ...
    @winrt_commethod(16)
    def SetPreviewPage(self, pageNumber: Int32, pageVisual: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(17)
    def InvalidatePreview(self) -> Void: ...
    DocumentSource = property(get_DocumentSource, None)
    Paginate = event()
    GetPreviewPage = event()
    AddPages = event()
class IPrintDocumentFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IPrintDocumentFactory'
    _iid_ = Guid('{fb87b18f-2606-4a2f-99d4-a7cdbc35d7c7}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Printing.PrintDocument: ...
class IPrintDocumentStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Xaml.Printing.IPrintDocumentStatics'
    _iid_ = Guid('{fd970a3c-b152-49e0-a6bd-6aa6477e43c7}')
    @winrt_commethod(6)
    def get_DocumentSourceProperty(self) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DocumentSourceProperty = property(get_DocumentSourceProperty, None)
class PaginateEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Xaml.Printing.IPaginateEventArgs
    _classid_ = 'Windows.UI.Xaml.Printing.PaginateEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Printing.PaginateEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.UI.Xaml.Printing.PaginateEventArgs: ...
    @winrt_mixinmethod
    def get_PrintTaskOptions(self: win32more.Windows.UI.Xaml.Printing.IPaginateEventArgs) -> win32more.Windows.Graphics.Printing.PrintTaskOptions: ...
    @winrt_mixinmethod
    def get_CurrentPreviewPageNumber(self: win32more.Windows.UI.Xaml.Printing.IPaginateEventArgs) -> Int32: ...
    CurrentPreviewPageNumber = property(get_CurrentPreviewPageNumber, None)
    PrintTaskOptions = property(get_PrintTaskOptions, None)
class PaginateEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0cc05b61-811b-4a32-9965-13eb78dbb01b}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Windows.UI.Xaml.Printing.PaginateEventArgs) -> Void: ...
class PreviewPageCountType(Enum, Int32):
    Final = 0
    Intermediate = 1
class _PrintDocument_Meta_(ComPtr.__class__):
    pass
class PrintDocument(ComPtr, metaclass=_PrintDocument_Meta_):
    extends: win32more.Windows.UI.Xaml.DependencyObject
    default_interface: win32more.Windows.UI.Xaml.Printing.IPrintDocument
    _classid_ = 'Windows.UI.Xaml.Printing.PrintDocument'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.UI.Xaml.Printing.PrintDocument.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.UI.Xaml.Printing.IPrintDocumentFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Windows.UI.Xaml.Printing.PrintDocument: ...
    @winrt_mixinmethod
    def get_DocumentSource(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument) -> win32more.Windows.Graphics.Printing.IPrintDocumentSource: ...
    @winrt_mixinmethod
    def add_Paginate(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, handler: win32more.Windows.UI.Xaml.Printing.PaginateEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Paginate(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_GetPreviewPage(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, handler: win32more.Windows.UI.Xaml.Printing.GetPreviewPageEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GetPreviewPage(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_AddPages(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, handler: win32more.Windows.UI.Xaml.Printing.AddPagesEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AddPages(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def AddPage(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, pageVisual: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def AddPagesComplete(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument) -> Void: ...
    @winrt_mixinmethod
    def SetPreviewPageCount(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, count: Int32, type: win32more.Windows.UI.Xaml.Printing.PreviewPageCountType) -> Void: ...
    @winrt_mixinmethod
    def SetPreviewPage(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument, pageNumber: Int32, pageVisual: win32more.Windows.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def InvalidatePreview(self: win32more.Windows.UI.Xaml.Printing.IPrintDocument) -> Void: ...
    @winrt_classmethod
    def get_DocumentSourceProperty(cls: win32more.Windows.UI.Xaml.Printing.IPrintDocumentStatics) -> win32more.Windows.UI.Xaml.DependencyProperty: ...
    DocumentSource = property(get_DocumentSource, None)
    _PrintDocument_Meta_.DocumentSourceProperty = property(get_DocumentSourceProperty, None)
    Paginate = event()
    GetPreviewPage = event()
    AddPages = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI.Dispatching
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class DispatcherExitDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Dispatching.IDispatcherExitDeferral
    _classid_ = 'Microsoft.UI.Dispatching.DispatcherExitDeferral'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Dispatching.DispatcherExitDeferral.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Dispatching.DispatcherExitDeferral: ...
    @winrt_mixinmethod
    def Complete(self: win32more.Microsoft.UI.Dispatching.IDispatcherExitDeferral) -> Void: ...
class DispatcherQueue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Dispatching.IDispatcherQueue
    _classid_ = 'Microsoft.UI.Dispatching.DispatcherQueue'
    @winrt_mixinmethod
    def remove_ShutdownCompleted(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def TryEnqueue(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, callback: win32more.Microsoft.UI.Dispatching.DispatcherQueueHandler) -> Boolean: ...
    @winrt_mixinmethod
    def TryEnqueueWithPriority(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, priority: win32more.Microsoft.UI.Dispatching.DispatcherQueuePriority, callback: win32more.Microsoft.UI.Dispatching.DispatcherQueueHandler) -> Boolean: ...
    @winrt_mixinmethod
    def CreateTimer(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueTimer: ...
    @winrt_mixinmethod
    def remove_ShutdownStarting(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ShutdownCompleted(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def add_ShutdownStarting(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Microsoft.UI.Dispatching.DispatcherQueueShutdownStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def get_HasThreadAccess(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue2) -> Boolean: ...
    @winrt_mixinmethod
    def EnqueueEventLoopExit(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3) -> Void: ...
    @winrt_mixinmethod
    def EnsureSystemDispatcherQueue(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3) -> Void: ...
    @winrt_mixinmethod
    def RunEventLoop(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3) -> Void: ...
    @winrt_mixinmethod
    def RunEventLoopWithOptions(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3, options: win32more.Microsoft.UI.Dispatching.DispatcherRunOptions, deferral: win32more.Microsoft.UI.Dispatching.DispatcherExitDeferral) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkShutdownStarting(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Microsoft.UI.Dispatching.DispatcherQueueShutdownStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkShutdownStarting(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FrameworkShutdownCompleted(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameworkShutdownCompleted(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueue3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def GetForCurrentThread(cls: win32more.Microsoft.UI.Dispatching.IDispatcherQueueStatics) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    HasThreadAccess = property(get_HasThreadAccess, None)
    ShutdownCompleted = event()
    ShutdownStarting = event()
    FrameworkShutdownStarting = event()
    FrameworkShutdownCompleted = event()
class DispatcherQueueController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Dispatching.IDispatcherQueueController
    _classid_ = 'Microsoft.UI.Dispatching.DispatcherQueueController'
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueController) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_mixinmethod
    def ShutdownQueueAsync(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueController) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShutdownQueue(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueController2) -> Void: ...
    @winrt_classmethod
    def CreateOnDedicatedThread(cls: win32more.Microsoft.UI.Dispatching.IDispatcherQueueControllerStatics) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueController: ...
    @winrt_classmethod
    def CreateOnCurrentThread(cls: win32more.Microsoft.UI.Dispatching.IDispatcherQueueControllerStatics) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueController: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
class DispatcherQueueHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2e0872a9-4e29-5f14-b688-fb96d5f9d5f8}')
    @winrt_commethod(3)
    def Invoke(self) -> Void: ...
class DispatcherQueuePriority(Enum, Int32):
    Low = -10
    Normal = 0
    High = 10
class DispatcherQueueShutdownStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Dispatching.IDispatcherQueueShutdownStartingEventArgs
    _classid_ = 'Microsoft.UI.Dispatching.DispatcherQueueShutdownStartingEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueShutdownStartingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class DispatcherQueueTimer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer
    _classid_ = 'Microsoft.UI.Dispatching.DispatcherQueueTimer'
    @winrt_mixinmethod
    def get_IsRunning(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer) -> Boolean: ...
    @winrt_mixinmethod
    def put_Interval(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def put_IsRepeating(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsRepeating(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer) -> Boolean: ...
    @winrt_mixinmethod
    def get_Interval(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def Start(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer) -> Void: ...
    @winrt_mixinmethod
    def add_Tick(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueueTimer, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Tick(self: win32more.Microsoft.UI.Dispatching.IDispatcherQueueTimer, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Interval = property(get_Interval, put_Interval)
    IsRepeating = property(get_IsRepeating, put_IsRepeating)
    IsRunning = property(get_IsRunning, None)
    Tick = event()
class DispatcherRunOptions(Enum, UInt32):
    None_ = 0
    ContinueOnQuit = 1
    QuitOnlyLocalLoop = 2
class IDispatcherExitDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherExitDeferral'
    _iid_ = Guid('{910b5aac-3310-563e-8418-f3005579729e}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IDispatcherQueue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueue'
    _iid_ = Guid('{f6ebf8fa-be1c-5bf6-a467-73da28738ae8}')
    @winrt_commethod(6)
    def CreateTimer(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueTimer: ...
    @winrt_commethod(7)
    def TryEnqueue(self, callback: win32more.Microsoft.UI.Dispatching.DispatcherQueueHandler) -> Boolean: ...
    @winrt_commethod(8)
    def TryEnqueueWithPriority(self, priority: win32more.Microsoft.UI.Dispatching.DispatcherQueuePriority, callback: win32more.Microsoft.UI.Dispatching.DispatcherQueueHandler) -> Boolean: ...
    @winrt_commethod(9)
    def add_ShutdownStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Microsoft.UI.Dispatching.DispatcherQueueShutdownStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_ShutdownStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_ShutdownCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_ShutdownCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ShutdownStarting = event()
    ShutdownCompleted = event()
class IDispatcherQueue2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueue2'
    _iid_ = Guid('{0cf48751-f1ac-59b8-ba52-6ce7a1444d6f}')
    @winrt_commethod(6)
    def get_HasThreadAccess(self) -> Boolean: ...
    HasThreadAccess = property(get_HasThreadAccess, None)
class IDispatcherQueue3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueue3'
    _iid_ = Guid('{14a7a175-5c27-5a35-b079-21960cf764a8}')
    @winrt_commethod(6)
    def EnqueueEventLoopExit(self) -> Void: ...
    @winrt_commethod(7)
    def EnsureSystemDispatcherQueue(self) -> Void: ...
    @winrt_commethod(8)
    def RunEventLoop(self) -> Void: ...
    @winrt_commethod(9)
    def RunEventLoopWithOptions(self, options: win32more.Microsoft.UI.Dispatching.DispatcherRunOptions, deferral: win32more.Microsoft.UI.Dispatching.DispatcherExitDeferral) -> Void: ...
    @winrt_commethod(10)
    def add_FrameworkShutdownStarting(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Microsoft.UI.Dispatching.DispatcherQueueShutdownStartingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_FrameworkShutdownStarting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_FrameworkShutdownCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueue, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_FrameworkShutdownCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    FrameworkShutdownStarting = event()
    FrameworkShutdownCompleted = event()
class IDispatcherQueueController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueController'
    _iid_ = Guid('{bce8178d-2183-584c-9e5b-f9366f6ae484}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_commethod(7)
    def ShutdownQueueAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
class IDispatcherQueueController2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueController2'
    _iid_ = Guid('{4c68ee2a-1cb1-5591-a3a2-9b590b8f8b9a}')
    @winrt_commethod(6)
    def ShutdownQueue(self) -> Void: ...
class IDispatcherQueueControllerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueControllerStatics'
    _iid_ = Guid('{f18d6145-722b-593d-bcf2-a61e713f0037}')
    @winrt_commethod(6)
    def CreateOnDedicatedThread(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueController: ...
    @winrt_commethod(7)
    def CreateOnCurrentThread(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueueController: ...
class IDispatcherQueueShutdownStartingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueShutdownStartingEventArgs'
    _iid_ = Guid('{32519be5-072b-5660-a70e-8835c9b8157d}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IDispatcherQueueStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueStatics'
    _iid_ = Guid('{cd3382ea-a455-5124-b63a-ca40d34ca23c}')
    @winrt_commethod(6)
    def GetForCurrentThread(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
class IDispatcherQueueTimer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Dispatching.IDispatcherQueueTimer'
    _iid_ = Guid('{ad4d63fd-88fe-541f-ac11-bf2dc1ed2ce5}')
    @winrt_commethod(6)
    def get_Interval(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_Interval(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(8)
    def get_IsRunning(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsRepeating(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsRepeating(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def Start(self) -> Void: ...
    @winrt_commethod(12)
    def Stop(self) -> Void: ...
    @winrt_commethod(13)
    def add_Tick(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Dispatching.DispatcherQueueTimer, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_Tick(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Interval = property(get_Interval, put_Interval)
    IsRepeating = property(get_IsRepeating, put_IsRepeating)
    IsRunning = property(get_IsRunning, None)
    Tick = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.DirectX.Direct3D11
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class BitmapAlphaMode(Enum, Int32):
    Premultiplied = 0
    Straight = 1
    Ignore = 2
class BitmapBounds(Structure):
    X: UInt32
    Y: UInt32
    Width: UInt32
    Height: UInt32
class BitmapBuffer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapBuffer
    _classid_ = 'Windows.Graphics.Imaging.BitmapBuffer'
    @winrt_mixinmethod
    def GetPlaneCount(self: win32more.Windows.Graphics.Imaging.IBitmapBuffer) -> Int32: ...
    @winrt_mixinmethod
    def GetPlaneDescription(self: win32more.Windows.Graphics.Imaging.IBitmapBuffer, index: Int32) -> win32more.Windows.Graphics.Imaging.BitmapPlaneDescription: ...
    @winrt_mixinmethod
    def CreateReference(self: win32more.Windows.Foundation.IMemoryBuffer) -> win32more.Windows.Foundation.IMemoryBufferReference: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class BitmapBufferAccessMode(Enum, Int32):
    Read = 0
    ReadWrite = 1
    Write = 2
class BitmapCodecInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapCodecInformation
    _classid_ = 'Windows.Graphics.Imaging.BitmapCodecInformation'
    @winrt_mixinmethod
    def get_CodecId(self: win32more.Windows.Graphics.Imaging.IBitmapCodecInformation) -> Guid: ...
    @winrt_mixinmethod
    def get_FileExtensions(self: win32more.Windows.Graphics.Imaging.IBitmapCodecInformation) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_FriendlyName(self: win32more.Windows.Graphics.Imaging.IBitmapCodecInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_MimeTypes(self: win32more.Windows.Graphics.Imaging.IBitmapCodecInformation) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    CodecId = property(get_CodecId, None)
    FileExtensions = property(get_FileExtensions, None)
    FriendlyName = property(get_FriendlyName, None)
    MimeTypes = property(get_MimeTypes, None)
class _BitmapDecoder_Meta_(ComPtr.__class__):
    pass
class BitmapDecoder(ComPtr, metaclass=_BitmapDecoder_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapDecoder
    _classid_ = 'Windows.Graphics.Imaging.BitmapDecoder'
    @winrt_mixinmethod
    def get_BitmapContainerProperties(self: win32more.Windows.Graphics.Imaging.IBitmapDecoder) -> win32more.Windows.Graphics.Imaging.BitmapPropertiesView: ...
    @winrt_mixinmethod
    def get_DecoderInformation(self: win32more.Windows.Graphics.Imaging.IBitmapDecoder) -> win32more.Windows.Graphics.Imaging.BitmapCodecInformation: ...
    @winrt_mixinmethod
    def get_FrameCount(self: win32more.Windows.Graphics.Imaging.IBitmapDecoder) -> UInt32: ...
    @winrt_mixinmethod
    def GetPreviewAsync(self: win32more.Windows.Graphics.Imaging.IBitmapDecoder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.ImageStream]: ...
    @winrt_mixinmethod
    def GetFrameAsync(self: win32more.Windows.Graphics.Imaging.IBitmapDecoder, frameIndex: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapFrame]: ...
    @winrt_mixinmethod
    def GetThumbnailAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.ImageStream]: ...
    @winrt_mixinmethod
    def get_BitmapProperties(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapPropertiesView: ...
    @winrt_mixinmethod
    def get_BitmapPixelFormat(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_mixinmethod
    def get_BitmapAlphaMode(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapAlphaMode: ...
    @winrt_mixinmethod
    def get_DpiX(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> Double: ...
    @winrt_mixinmethod
    def get_DpiY(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> Double: ...
    @winrt_mixinmethod
    def get_PixelWidth(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_PixelHeight(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_OrientedPixelWidth(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_OrientedPixelHeight(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def GetPixelDataAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    @winrt_mixinmethod
    def GetPixelDataTransformedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapConvertedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapTransformedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_classmethod
    def get_HeifDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics2) -> Guid: ...
    @winrt_classmethod
    def get_WebpDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics2) -> Guid: ...
    @winrt_classmethod
    def get_BmpDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_JpegDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_PngDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_TiffDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_GifDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_JpegXRDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_IcoDecoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> Guid: ...
    @winrt_classmethod
    def GetDecoderInformationEnumerator(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapCodecInformation]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapDecoder]: ...
    @winrt_classmethod
    def CreateWithIdAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapDecoderStatics, decoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapDecoder]: ...
    BitmapAlphaMode = property(get_BitmapAlphaMode, None)
    BitmapContainerProperties = property(get_BitmapContainerProperties, None)
    BitmapPixelFormat = property(get_BitmapPixelFormat, None)
    BitmapProperties = property(get_BitmapProperties, None)
    DecoderInformation = property(get_DecoderInformation, None)
    DpiX = property(get_DpiX, None)
    DpiY = property(get_DpiY, None)
    FrameCount = property(get_FrameCount, None)
    OrientedPixelHeight = property(get_OrientedPixelHeight, None)
    OrientedPixelWidth = property(get_OrientedPixelWidth, None)
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
    _BitmapDecoder_Meta_.BmpDecoderId = property(get_BmpDecoderId, None)
    _BitmapDecoder_Meta_.GifDecoderId = property(get_GifDecoderId, None)
    _BitmapDecoder_Meta_.HeifDecoderId = property(get_HeifDecoderId, None)
    _BitmapDecoder_Meta_.IcoDecoderId = property(get_IcoDecoderId, None)
    _BitmapDecoder_Meta_.JpegDecoderId = property(get_JpegDecoderId, None)
    _BitmapDecoder_Meta_.JpegXRDecoderId = property(get_JpegXRDecoderId, None)
    _BitmapDecoder_Meta_.PngDecoderId = property(get_PngDecoderId, None)
    _BitmapDecoder_Meta_.TiffDecoderId = property(get_TiffDecoderId, None)
    _BitmapDecoder_Meta_.WebpDecoderId = property(get_WebpDecoderId, None)
class _BitmapEncoder_Meta_(ComPtr.__class__):
    pass
class BitmapEncoder(ComPtr, metaclass=_BitmapEncoder_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapEncoder
    _classid_ = 'Windows.Graphics.Imaging.BitmapEncoder'
    @winrt_mixinmethod
    def get_EncoderInformation(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Graphics.Imaging.BitmapCodecInformation: ...
    @winrt_mixinmethod
    def get_BitmapProperties(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Graphics.Imaging.BitmapProperties: ...
    @winrt_mixinmethod
    def get_BitmapContainerProperties(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Graphics.Imaging.BitmapProperties: ...
    @winrt_mixinmethod
    def get_IsThumbnailGenerated(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsThumbnailGenerated(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_GeneratedThumbnailWidth(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> UInt32: ...
    @winrt_mixinmethod
    def put_GeneratedThumbnailWidth(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_GeneratedThumbnailHeight(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> UInt32: ...
    @winrt_mixinmethod
    def put_GeneratedThumbnailHeight(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_BitmapTransform(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Graphics.Imaging.BitmapTransform: ...
    @winrt_mixinmethod
    def SetPixelData(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, width: UInt32, height: UInt32, dpiX: Double, dpiY: Double, pixels: PassArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def GoToNextFrameAsync(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GoToNextFrameWithEncodingOptionsAsync(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder, encodingOptions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Graphics.Imaging.IBitmapEncoder) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def SetSoftwareBitmap(self: win32more.Windows.Graphics.Imaging.IBitmapEncoderWithSoftwareBitmap, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_classmethod
    def get_HeifEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics2) -> Guid: ...
    @winrt_classmethod
    def get_BmpEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_JpegEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_PngEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_TiffEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_GifEncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def get_JpegXREncoderId(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> Guid: ...
    @winrt_classmethod
    def GetEncoderInformationEnumerator(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapCodecInformation]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics, encoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_classmethod
    def CreateWithEncodingOptionsAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics, encoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, encodingOptions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_classmethod
    def CreateForTranscodingAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, bitmapDecoder: win32more.Windows.Graphics.Imaging.BitmapDecoder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_classmethod
    def CreateForInPlacePropertyEncodingAsync(cls: win32more.Windows.Graphics.Imaging.IBitmapEncoderStatics, bitmapDecoder: win32more.Windows.Graphics.Imaging.BitmapDecoder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    BitmapContainerProperties = property(get_BitmapContainerProperties, None)
    BitmapProperties = property(get_BitmapProperties, None)
    BitmapTransform = property(get_BitmapTransform, None)
    EncoderInformation = property(get_EncoderInformation, None)
    GeneratedThumbnailHeight = property(get_GeneratedThumbnailHeight, put_GeneratedThumbnailHeight)
    GeneratedThumbnailWidth = property(get_GeneratedThumbnailWidth, put_GeneratedThumbnailWidth)
    IsThumbnailGenerated = property(get_IsThumbnailGenerated, put_IsThumbnailGenerated)
    _BitmapEncoder_Meta_.BmpEncoderId = property(get_BmpEncoderId, None)
    _BitmapEncoder_Meta_.GifEncoderId = property(get_GifEncoderId, None)
    _BitmapEncoder_Meta_.HeifEncoderId = property(get_HeifEncoderId, None)
    _BitmapEncoder_Meta_.JpegEncoderId = property(get_JpegEncoderId, None)
    _BitmapEncoder_Meta_.JpegXREncoderId = property(get_JpegXREncoderId, None)
    _BitmapEncoder_Meta_.PngEncoderId = property(get_PngEncoderId, None)
    _BitmapEncoder_Meta_.TiffEncoderId = property(get_TiffEncoderId, None)
class BitmapFlip(Enum, Int32):
    None_ = 0
    Horizontal = 1
    Vertical = 2
class BitmapFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapFrame
    _classid_ = 'Windows.Graphics.Imaging.BitmapFrame'
    @winrt_mixinmethod
    def GetThumbnailAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.ImageStream]: ...
    @winrt_mixinmethod
    def get_BitmapProperties(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapPropertiesView: ...
    @winrt_mixinmethod
    def get_BitmapPixelFormat(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_mixinmethod
    def get_BitmapAlphaMode(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Graphics.Imaging.BitmapAlphaMode: ...
    @winrt_mixinmethod
    def get_DpiX(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> Double: ...
    @winrt_mixinmethod
    def get_DpiY(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> Double: ...
    @winrt_mixinmethod
    def get_PixelWidth(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_PixelHeight(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_OrientedPixelWidth(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_OrientedPixelHeight(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> UInt32: ...
    @winrt_mixinmethod
    def GetPixelDataAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    @winrt_mixinmethod
    def GetPixelDataTransformedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrame, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapConvertedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_mixinmethod
    def GetSoftwareBitmapTransformedAsync(self: win32more.Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    BitmapAlphaMode = property(get_BitmapAlphaMode, None)
    BitmapPixelFormat = property(get_BitmapPixelFormat, None)
    BitmapProperties = property(get_BitmapProperties, None)
    DpiX = property(get_DpiX, None)
    DpiY = property(get_DpiY, None)
    OrientedPixelHeight = property(get_OrientedPixelHeight, None)
    OrientedPixelWidth = property(get_OrientedPixelWidth, None)
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class BitmapInterpolationMode(Enum, Int32):
    NearestNeighbor = 0
    Linear = 1
    Cubic = 2
    Fant = 3
class BitmapPixelFormat(Enum, Int32):
    Unknown = 0
    Rgba16 = 12
    Rgba8 = 30
    Gray16 = 57
    Gray8 = 62
    Bgra8 = 87
    Nv12 = 103
    P010 = 104
    Yuy2 = 107
class BitmapPlaneDescription(Structure):
    StartIndex: Int32
    Width: Int32
    Height: Int32
    Stride: Int32
class BitmapProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapProperties
    _classid_ = 'Windows.Graphics.Imaging.BitmapProperties'
    @winrt_mixinmethod
    def SetPropertiesAsync(self: win32more.Windows.Graphics.Imaging.IBitmapProperties, propertiesToSet: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetPropertiesAsync(self: win32more.Windows.Graphics.Imaging.IBitmapPropertiesView, propertiesToRetrieve: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapPropertySet]: ...
class BitmapPropertiesView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapPropertiesView
    _classid_ = 'Windows.Graphics.Imaging.BitmapPropertiesView'
    @winrt_mixinmethod
    def GetPropertiesAsync(self: win32more.Windows.Graphics.Imaging.IBitmapPropertiesView, propertiesToRetrieve: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapPropertySet]: ...
class BitmapPropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[MappingProtocol[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]
    default_interface: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]
    _classid_ = 'Windows.Graphics.Imaging.BitmapPropertySet'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Graphics.Imaging.BitmapPropertySet.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Graphics.Imaging.BitmapPropertySet: ...
    @winrt_mixinmethod
    def Lookup(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue], key: WinRT_String) -> win32more.Windows.Graphics.Imaging.BitmapTypedValue: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]) -> UInt32: ...
    @winrt_mixinmethod
    def HasKey(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue], key: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def GetView(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]: ...
    @winrt_mixinmethod
    def Insert(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue], key: WinRT_String, value: win32more.Windows.Graphics.Imaging.BitmapTypedValue) -> Boolean: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue], key: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Clear(self: win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]) -> Void: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]: ...
    Size = property(get_Size, None)
class BitmapRotation(Enum, Int32):
    None_ = 0
    Clockwise90Degrees = 1
    Clockwise180Degrees = 2
    Clockwise270Degrees = 3
class BitmapSize(Structure):
    Width: UInt32
    Height: UInt32
class BitmapTransform(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapTransform
    _classid_ = 'Windows.Graphics.Imaging.BitmapTransform'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Graphics.Imaging.BitmapTransform.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Graphics.Imaging.BitmapTransform: ...
    @winrt_mixinmethod
    def get_ScaledWidth(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> UInt32: ...
    @winrt_mixinmethod
    def put_ScaledWidth(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ScaledHeight(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> UInt32: ...
    @winrt_mixinmethod
    def put_ScaledHeight(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_InterpolationMode(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> win32more.Windows.Graphics.Imaging.BitmapInterpolationMode: ...
    @winrt_mixinmethod
    def put_InterpolationMode(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: win32more.Windows.Graphics.Imaging.BitmapInterpolationMode) -> Void: ...
    @winrt_mixinmethod
    def get_Flip(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> win32more.Windows.Graphics.Imaging.BitmapFlip: ...
    @winrt_mixinmethod
    def put_Flip(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: win32more.Windows.Graphics.Imaging.BitmapFlip) -> Void: ...
    @winrt_mixinmethod
    def get_Rotation(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> win32more.Windows.Graphics.Imaging.BitmapRotation: ...
    @winrt_mixinmethod
    def put_Rotation(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: win32more.Windows.Graphics.Imaging.BitmapRotation) -> Void: ...
    @winrt_mixinmethod
    def get_Bounds(self: win32more.Windows.Graphics.Imaging.IBitmapTransform) -> win32more.Windows.Graphics.Imaging.BitmapBounds: ...
    @winrt_mixinmethod
    def put_Bounds(self: win32more.Windows.Graphics.Imaging.IBitmapTransform, value: win32more.Windows.Graphics.Imaging.BitmapBounds) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Flip = property(get_Flip, put_Flip)
    InterpolationMode = property(get_InterpolationMode, put_InterpolationMode)
    Rotation = property(get_Rotation, put_Rotation)
    ScaledHeight = property(get_ScaledHeight, put_ScaledHeight)
    ScaledWidth = property(get_ScaledWidth, put_ScaledWidth)
class BitmapTypedValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IBitmapTypedValue
    _classid_ = 'Windows.Graphics.Imaging.BitmapTypedValue'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Graphics.Imaging.BitmapTypedValue.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Graphics.Imaging.IBitmapTypedValueFactory, value: win32more.Windows.Win32.System.WinRT.IInspectable, type: win32more.Windows.Foundation.PropertyType) -> win32more.Windows.Graphics.Imaging.BitmapTypedValue: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Imaging.IBitmapTypedValue) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Graphics.Imaging.IBitmapTypedValue) -> win32more.Windows.Foundation.PropertyType: ...
    Type = property(get_Type, None)
    Value = property(get_Value, None)
class ColorManagementMode(Enum, Int32):
    DoNotColorManage = 0
    ColorManageToSRgb = 1
class ExifOrientationMode(Enum, Int32):
    IgnoreExifOrientation = 0
    RespectExifOrientation = 1
class IBitmapBuffer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Graphics.Imaging.IBitmapBuffer'
    _iid_ = Guid('{a53e04c4-399c-438c-b28f-a63a6b83d1a1}')
    @winrt_commethod(6)
    def GetPlaneCount(self) -> Int32: ...
    @winrt_commethod(7)
    def GetPlaneDescription(self, index: Int32) -> win32more.Windows.Graphics.Imaging.BitmapPlaneDescription: ...
class IBitmapCodecInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapCodecInformation'
    _iid_ = Guid('{400caaf2-c4b0-4392-a3b0-6f6f9ba95cb4}')
    @winrt_commethod(6)
    def get_CodecId(self) -> Guid: ...
    @winrt_commethod(7)
    def get_FileExtensions(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(8)
    def get_FriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_MimeTypes(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    CodecId = property(get_CodecId, None)
    FileExtensions = property(get_FileExtensions, None)
    FriendlyName = property(get_FriendlyName, None)
    MimeTypes = property(get_MimeTypes, None)
class IBitmapDecoder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapDecoder'
    _iid_ = Guid('{acef22ba-1d74-4c91-9dfc-9620745233e6}')
    @winrt_commethod(6)
    def get_BitmapContainerProperties(self) -> win32more.Windows.Graphics.Imaging.BitmapPropertiesView: ...
    @winrt_commethod(7)
    def get_DecoderInformation(self) -> win32more.Windows.Graphics.Imaging.BitmapCodecInformation: ...
    @winrt_commethod(8)
    def get_FrameCount(self) -> UInt32: ...
    @winrt_commethod(9)
    def GetPreviewAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.ImageStream]: ...
    @winrt_commethod(10)
    def GetFrameAsync(self, frameIndex: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapFrame]: ...
    BitmapContainerProperties = property(get_BitmapContainerProperties, None)
    DecoderInformation = property(get_DecoderInformation, None)
    FrameCount = property(get_FrameCount, None)
class IBitmapDecoderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapDecoderStatics'
    _iid_ = Guid('{438ccb26-bcef-4e95-bad6-23a822e58d01}')
    @winrt_commethod(6)
    def get_BmpDecoderId(self) -> Guid: ...
    @winrt_commethod(7)
    def get_JpegDecoderId(self) -> Guid: ...
    @winrt_commethod(8)
    def get_PngDecoderId(self) -> Guid: ...
    @winrt_commethod(9)
    def get_TiffDecoderId(self) -> Guid: ...
    @winrt_commethod(10)
    def get_GifDecoderId(self) -> Guid: ...
    @winrt_commethod(11)
    def get_JpegXRDecoderId(self) -> Guid: ...
    @winrt_commethod(12)
    def get_IcoDecoderId(self) -> Guid: ...
    @winrt_commethod(13)
    def GetDecoderInformationEnumerator(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapCodecInformation]: ...
    @winrt_commethod(14)
    def CreateAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapDecoder]: ...
    @winrt_commethod(15)
    def CreateWithIdAsync(self, decoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapDecoder]: ...
    BmpDecoderId = property(get_BmpDecoderId, None)
    GifDecoderId = property(get_GifDecoderId, None)
    IcoDecoderId = property(get_IcoDecoderId, None)
    JpegDecoderId = property(get_JpegDecoderId, None)
    JpegXRDecoderId = property(get_JpegXRDecoderId, None)
    PngDecoderId = property(get_PngDecoderId, None)
    TiffDecoderId = property(get_TiffDecoderId, None)
class IBitmapDecoderStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapDecoderStatics2'
    _iid_ = Guid('{50ba68ea-99a1-40c4-80d9-aef0dafa6c3f}')
    @winrt_commethod(6)
    def get_HeifDecoderId(self) -> Guid: ...
    @winrt_commethod(7)
    def get_WebpDecoderId(self) -> Guid: ...
    HeifDecoderId = property(get_HeifDecoderId, None)
    WebpDecoderId = property(get_WebpDecoderId, None)
class IBitmapEncoder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapEncoder'
    _iid_ = Guid('{2bc468e3-e1f8-4b54-95e8-32919551ce62}')
    @winrt_commethod(6)
    def get_EncoderInformation(self) -> win32more.Windows.Graphics.Imaging.BitmapCodecInformation: ...
    @winrt_commethod(7)
    def get_BitmapProperties(self) -> win32more.Windows.Graphics.Imaging.BitmapProperties: ...
    @winrt_commethod(8)
    def get_BitmapContainerProperties(self) -> win32more.Windows.Graphics.Imaging.BitmapProperties: ...
    @winrt_commethod(9)
    def get_IsThumbnailGenerated(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsThumbnailGenerated(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_GeneratedThumbnailWidth(self) -> UInt32: ...
    @winrt_commethod(12)
    def put_GeneratedThumbnailWidth(self, value: UInt32) -> Void: ...
    @winrt_commethod(13)
    def get_GeneratedThumbnailHeight(self) -> UInt32: ...
    @winrt_commethod(14)
    def put_GeneratedThumbnailHeight(self, value: UInt32) -> Void: ...
    @winrt_commethod(15)
    def get_BitmapTransform(self) -> win32more.Windows.Graphics.Imaging.BitmapTransform: ...
    @winrt_commethod(16)
    def SetPixelData(self, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, width: UInt32, height: UInt32, dpiX: Double, dpiY: Double, pixels: PassArray[Byte]) -> Void: ...
    @winrt_commethod(17)
    def GoToNextFrameAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(18)
    def GoToNextFrameWithEncodingOptionsAsync(self, encodingOptions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(19)
    def FlushAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    BitmapContainerProperties = property(get_BitmapContainerProperties, None)
    BitmapProperties = property(get_BitmapProperties, None)
    BitmapTransform = property(get_BitmapTransform, None)
    EncoderInformation = property(get_EncoderInformation, None)
    GeneratedThumbnailHeight = property(get_GeneratedThumbnailHeight, put_GeneratedThumbnailHeight)
    GeneratedThumbnailWidth = property(get_GeneratedThumbnailWidth, put_GeneratedThumbnailWidth)
    IsThumbnailGenerated = property(get_IsThumbnailGenerated, put_IsThumbnailGenerated)
class IBitmapEncoderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapEncoderStatics'
    _iid_ = Guid('{a74356a7-a4e4-4eb9-8e40-564de7e1ccb2}')
    @winrt_commethod(6)
    def get_BmpEncoderId(self) -> Guid: ...
    @winrt_commethod(7)
    def get_JpegEncoderId(self) -> Guid: ...
    @winrt_commethod(8)
    def get_PngEncoderId(self) -> Guid: ...
    @winrt_commethod(9)
    def get_TiffEncoderId(self) -> Guid: ...
    @winrt_commethod(10)
    def get_GifEncoderId(self) -> Guid: ...
    @winrt_commethod(11)
    def get_JpegXREncoderId(self) -> Guid: ...
    @winrt_commethod(12)
    def GetEncoderInformationEnumerator(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Imaging.BitmapCodecInformation]: ...
    @winrt_commethod(13)
    def CreateAsync(self, encoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_commethod(14)
    def CreateWithEncodingOptionsAsync(self, encoderId: Guid, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, encodingOptions: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_commethod(15)
    def CreateForTranscodingAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStream, bitmapDecoder: win32more.Windows.Graphics.Imaging.BitmapDecoder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    @winrt_commethod(16)
    def CreateForInPlacePropertyEncodingAsync(self, bitmapDecoder: win32more.Windows.Graphics.Imaging.BitmapDecoder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapEncoder]: ...
    BmpEncoderId = property(get_BmpEncoderId, None)
    GifEncoderId = property(get_GifEncoderId, None)
    JpegEncoderId = property(get_JpegEncoderId, None)
    JpegXREncoderId = property(get_JpegXREncoderId, None)
    PngEncoderId = property(get_PngEncoderId, None)
    TiffEncoderId = property(get_TiffEncoderId, None)
class IBitmapEncoderStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapEncoderStatics2'
    _iid_ = Guid('{33cbc259-fe31-41b1-b812-086d21e87e16}')
    @winrt_commethod(6)
    def get_HeifEncoderId(self) -> Guid: ...
    HeifEncoderId = property(get_HeifEncoderId, None)
class IBitmapEncoderWithSoftwareBitmap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapEncoderWithSoftwareBitmap'
    _iid_ = Guid('{686cd241-4330-4c77-ace4-0334968b1768}')
    @winrt_commethod(6)
    def SetSoftwareBitmap(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
class IBitmapFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapFrame'
    _iid_ = Guid('{72a49a1c-8081-438d-91bc-94ecfc8185c6}')
    @winrt_commethod(6)
    def GetThumbnailAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.ImageStream]: ...
    @winrt_commethod(7)
    def get_BitmapProperties(self) -> win32more.Windows.Graphics.Imaging.BitmapPropertiesView: ...
    @winrt_commethod(8)
    def get_BitmapPixelFormat(self) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_commethod(9)
    def get_BitmapAlphaMode(self) -> win32more.Windows.Graphics.Imaging.BitmapAlphaMode: ...
    @winrt_commethod(10)
    def get_DpiX(self) -> Double: ...
    @winrt_commethod(11)
    def get_DpiY(self) -> Double: ...
    @winrt_commethod(12)
    def get_PixelWidth(self) -> UInt32: ...
    @winrt_commethod(13)
    def get_PixelHeight(self) -> UInt32: ...
    @winrt_commethod(14)
    def get_OrientedPixelWidth(self) -> UInt32: ...
    @winrt_commethod(15)
    def get_OrientedPixelHeight(self) -> UInt32: ...
    @winrt_commethod(16)
    def GetPixelDataAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    @winrt_commethod(17)
    def GetPixelDataTransformedAsync(self, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.PixelDataProvider]: ...
    BitmapAlphaMode = property(get_BitmapAlphaMode, None)
    BitmapPixelFormat = property(get_BitmapPixelFormat, None)
    BitmapProperties = property(get_BitmapProperties, None)
    DpiX = property(get_DpiX, None)
    DpiY = property(get_DpiY, None)
    OrientedPixelHeight = property(get_OrientedPixelHeight, None)
    OrientedPixelWidth = property(get_OrientedPixelWidth, None)
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class IBitmapFrameWithSoftwareBitmap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapFrameWithSoftwareBitmap'
    _iid_ = Guid('{fe287c9a-420c-4963-87ad-691436e08383}')
    @winrt_commethod(6)
    def GetSoftwareBitmapAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_commethod(7)
    def GetSoftwareBitmapConvertedAsync(self, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_commethod(8)
    def GetSoftwareBitmapTransformedAsync(self, pixelFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alphaMode: win32more.Windows.Graphics.Imaging.BitmapAlphaMode, transform: win32more.Windows.Graphics.Imaging.BitmapTransform, exifOrientationMode: win32more.Windows.Graphics.Imaging.ExifOrientationMode, colorManagementMode: win32more.Windows.Graphics.Imaging.ColorManagementMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
class IBitmapProperties(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapProperties'
    _iid_ = Guid('{ea9f4f1b-b505-4450-a4d1-e8ca94529d8d}')
    @winrt_commethod(6)
    def SetPropertiesAsync(self, propertiesToSet: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, win32more.Windows.Graphics.Imaging.BitmapTypedValue]]) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBitmapPropertiesView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapPropertiesView'
    _iid_ = Guid('{7e0fe87a-3a70-48f8-9c55-196cf5a545f5}')
    @winrt_commethod(6)
    def GetPropertiesAsync(self, propertiesToRetrieve: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.BitmapPropertySet]: ...
class IBitmapTransform(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapTransform'
    _iid_ = Guid('{ae755344-e268-4d35-adcf-e995d31a8d34}')
    @winrt_commethod(6)
    def get_ScaledWidth(self) -> UInt32: ...
    @winrt_commethod(7)
    def put_ScaledWidth(self, value: UInt32) -> Void: ...
    @winrt_commethod(8)
    def get_ScaledHeight(self) -> UInt32: ...
    @winrt_commethod(9)
    def put_ScaledHeight(self, value: UInt32) -> Void: ...
    @winrt_commethod(10)
    def get_InterpolationMode(self) -> win32more.Windows.Graphics.Imaging.BitmapInterpolationMode: ...
    @winrt_commethod(11)
    def put_InterpolationMode(self, value: win32more.Windows.Graphics.Imaging.BitmapInterpolationMode) -> Void: ...
    @winrt_commethod(12)
    def get_Flip(self) -> win32more.Windows.Graphics.Imaging.BitmapFlip: ...
    @winrt_commethod(13)
    def put_Flip(self, value: win32more.Windows.Graphics.Imaging.BitmapFlip) -> Void: ...
    @winrt_commethod(14)
    def get_Rotation(self) -> win32more.Windows.Graphics.Imaging.BitmapRotation: ...
    @winrt_commethod(15)
    def put_Rotation(self, value: win32more.Windows.Graphics.Imaging.BitmapRotation) -> Void: ...
    @winrt_commethod(16)
    def get_Bounds(self) -> win32more.Windows.Graphics.Imaging.BitmapBounds: ...
    @winrt_commethod(17)
    def put_Bounds(self, value: win32more.Windows.Graphics.Imaging.BitmapBounds) -> Void: ...
    Bounds = property(get_Bounds, put_Bounds)
    Flip = property(get_Flip, put_Flip)
    InterpolationMode = property(get_InterpolationMode, put_InterpolationMode)
    Rotation = property(get_Rotation, put_Rotation)
    ScaledHeight = property(get_ScaledHeight, put_ScaledHeight)
    ScaledWidth = property(get_ScaledWidth, put_ScaledWidth)
class IBitmapTypedValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapTypedValue'
    _iid_ = Guid('{cd8044a9-2443-4000-b0cd-79316c56f589}')
    @winrt_commethod(6)
    def get_Value(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_Type(self) -> win32more.Windows.Foundation.PropertyType: ...
    Type = property(get_Type, None)
    Value = property(get_Value, None)
class IBitmapTypedValueFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IBitmapTypedValueFactory'
    _iid_ = Guid('{92dbb599-ce13-46bb-9545-cb3a3f63eb8b}')
    @winrt_commethod(6)
    def Create(self, value: win32more.Windows.Win32.System.WinRT.IInspectable, type: win32more.Windows.Foundation.PropertyType) -> win32more.Windows.Graphics.Imaging.BitmapTypedValue: ...
class IPixelDataProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.IPixelDataProvider'
    _iid_ = Guid('{dd831f25-185c-4595-9fb9-ccbe6ec18a6f}')
    @winrt_commethod(6)
    def DetachPixelData(self) -> ReceiveArray[Byte]: ...
class ISoftwareBitmap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Graphics.Imaging.ISoftwareBitmap'
    _iid_ = Guid('{689e0708-7eef-483f-963f-da938818e073}')
    @winrt_commethod(6)
    def get_BitmapPixelFormat(self) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_commethod(7)
    def get_BitmapAlphaMode(self) -> win32more.Windows.Graphics.Imaging.BitmapAlphaMode: ...
    @winrt_commethod(8)
    def get_PixelWidth(self) -> Int32: ...
    @winrt_commethod(9)
    def get_PixelHeight(self) -> Int32: ...
    @winrt_commethod(10)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_DpiX(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_DpiX(self) -> Double: ...
    @winrt_commethod(13)
    def put_DpiY(self, value: Double) -> Void: ...
    @winrt_commethod(14)
    def get_DpiY(self) -> Double: ...
    @winrt_commethod(15)
    def LockBuffer(self, mode: win32more.Windows.Graphics.Imaging.BitmapBufferAccessMode) -> win32more.Windows.Graphics.Imaging.BitmapBuffer: ...
    @winrt_commethod(16)
    def CopyTo(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_commethod(17)
    def CopyFromBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(18)
    def CopyToBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(19)
    def GetReadOnlyView(self) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    BitmapAlphaMode = property(get_BitmapAlphaMode, None)
    BitmapPixelFormat = property(get_BitmapPixelFormat, None)
    DpiX = property(get_DpiX, put_DpiX)
    DpiY = property(get_DpiY, put_DpiY)
    IsReadOnly = property(get_IsReadOnly, None)
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class ISoftwareBitmapFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.ISoftwareBitmapFactory'
    _iid_ = Guid('{c99feb69-2d62-4d47-a6b3-4fdb6a07fdf8}')
    @winrt_commethod(6)
    def Create(self, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(7)
    def CreateWithAlpha(self, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
class ISoftwareBitmapStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Imaging.ISoftwareBitmapStatics'
    _iid_ = Guid('{df0385db-672f-4a9d-806e-c2442f343e86}')
    @winrt_commethod(6)
    def Copy(self, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(7)
    def Convert(self, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(8)
    def ConvertWithAlpha(self, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(9)
    def CreateCopyFromBuffer(self, source: win32more.Windows.Storage.Streams.IBuffer, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(10)
    def CreateCopyWithAlphaFromBuffer(self, source: win32more.Windows.Storage.Streams.IBuffer, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(11)
    def CreateCopyFromSurfaceAsync(self, surface: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_commethod(12)
    def CreateCopyWithAlphaFromSurfaceAsync(self, surface: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
class ImageStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType
    _classid_ = 'Windows.Graphics.Imaging.ImageStream'
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def put_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def GetInputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def GetOutputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def Seek(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> Void: ...
    @winrt_mixinmethod
    def CloneStream(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def get_CanRead(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanWrite(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_ContentType(self: win32more.Windows.Storage.Streams.IContentTypeProvider) -> WinRT_String: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    ContentType = property(get_ContentType, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
class JpegSubsamplingMode(Enum, Int32):
    Default = 0
    Y4Cb2Cr0 = 1
    Y4Cb2Cr2 = 2
    Y4Cb4Cr4 = 3
class PixelDataProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Imaging.IPixelDataProvider
    _classid_ = 'Windows.Graphics.Imaging.PixelDataProvider'
    @winrt_mixinmethod
    def DetachPixelData(self: win32more.Windows.Graphics.Imaging.IPixelDataProvider) -> ReceiveArray[Byte]: ...
class PngFilterMode(Enum, Int32):
    Automatic = 0
    None_ = 1
    Sub = 2
    Up = 3
    Average = 4
    Paeth = 5
    Adaptive = 6
class SoftwareBitmap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Graphics.Imaging.ISoftwareBitmap
    _classid_ = 'Windows.Graphics.Imaging.SoftwareBitmap'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.Graphics.Imaging.SoftwareBitmap.Create(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.Graphics.Imaging.SoftwareBitmap.CreateWithAlpha(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapFactory, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_factorymethod
    def CreateWithAlpha(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapFactory, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_mixinmethod
    def get_BitmapPixelFormat(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_mixinmethod
    def get_BitmapAlphaMode(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> win32more.Windows.Graphics.Imaging.BitmapAlphaMode: ...
    @winrt_mixinmethod
    def get_PixelWidth(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> Int32: ...
    @winrt_mixinmethod
    def get_PixelHeight(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> Int32: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> Boolean: ...
    @winrt_mixinmethod
    def put_DpiX(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_DpiX(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> Double: ...
    @winrt_mixinmethod
    def put_DpiY(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_DpiY(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> Double: ...
    @winrt_mixinmethod
    def LockBuffer(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, mode: win32more.Windows.Graphics.Imaging.BitmapBufferAccessMode) -> win32more.Windows.Graphics.Imaging.BitmapBuffer: ...
    @winrt_mixinmethod
    def CopyTo(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    @winrt_mixinmethod
    def CopyFromBuffer(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def CopyToBuffer(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def GetReadOnlyView(self: win32more.Windows.Graphics.Imaging.ISoftwareBitmap) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def Copy(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_classmethod
    def Convert(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_classmethod
    def ConvertWithAlpha(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, source: win32more.Windows.Graphics.Imaging.SoftwareBitmap, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_classmethod
    def CreateCopyFromBuffer(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, source: win32more.Windows.Storage.Streams.IBuffer, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_classmethod
    def CreateCopyWithAlphaFromBuffer(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, source: win32more.Windows.Storage.Streams.IBuffer, format: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, width: Int32, height: Int32, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_classmethod
    def CreateCopyFromSurfaceAsync(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, surface: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    @winrt_classmethod
    def CreateCopyWithAlphaFromSurfaceAsync(cls: win32more.Windows.Graphics.Imaging.ISoftwareBitmapStatics, surface: win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface, alpha: win32more.Windows.Graphics.Imaging.BitmapAlphaMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Imaging.SoftwareBitmap]: ...
    BitmapAlphaMode = property(get_BitmapAlphaMode, None)
    BitmapPixelFormat = property(get_BitmapPixelFormat, None)
    DpiX = property(get_DpiX, put_DpiX)
    DpiY = property(get_DpiY, put_DpiY)
    IsReadOnly = property(get_IsReadOnly, None)
    PixelHeight = property(get_PixelHeight, None)
    PixelWidth = property(get_PixelWidth, None)
class TiffCompressionMode(Enum, Int32):
    Automatic = 0
    None_ = 1
    Ccitt3 = 2
    Ccitt4 = 3
    Lzw = 4
    Rle = 5
    Zip = 6
    LzwhDifferencing = 7


make_ready(__name__)
